==> kea-docs-2.6.2-1-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/d6/def/lease__cmds__messages_8cc.js <==
var lease__cmds__messages_8cc =
[
    [ "LEASE_CMDS_ADD4", "d6/def/lease__cmds__messages_8cc.html#a8b26cafbe313dea87c4b60e9d2412c36", null ],
    [ "LEASE_CMDS_ADD4_CONFLICT", "d6/def/lease__cmds__messages_8cc.html#ac078b8f536f9c73a17282b7cf724eceb", null ],
    [ "LEASE_CMDS_ADD4_FAILED", "d6/def/lease__cmds__messages_8cc.html#a39b8134e5fe6a43b1953a151991719fe", null ],
    [ "LEASE_CMDS_ADD6", "d6/def/lease__cmds__messages_8cc.html#a872931e538e61db539b0eb6ea7f327e1", null ],
    [ "LEASE_CMDS_ADD6_CONFLICT", "d6/def/lease__cmds__messages_8cc.html#a988c549dc02e2788be0fd470809d82a2", null ],
    [ "LEASE_CMDS_ADD6_FAILED", "d6/def/lease__cmds__messages_8cc.html#ac67f38db4dfddda9cbeb51b7906cca98", null ],
    [ "LEASE_CMDS_BULK_APPLY6", "d6/def/lease__cmds__messages_8cc.html#ab37d3e76f7f362d27e9655949b41158f", null ],
    [ "LEASE_CMDS_BULK_APPLY6_FAILED", "d6/def/lease__cmds__messages_8cc.html#a9b077c8d4dc62189ec1e7a89b6bea11a", null ],
    [ "LEASE_CMDS_DEINIT_FAILED", "d6/def/lease__cmds__messages_8cc.html#af57330d917114a196e2356a334a4ce2c", null ],
    [ "LEASE_CMDS_DEINIT_OK", "d6/def/lease__cmds__messages_8cc.html#a3eabc702a2efe993afae67a3a0a2f771", null ],
    [ "LEASE_CMDS_DEL4", "d6/def/lease__cmds__messages_8cc.html#a0a2e211528e7ac391e2174f3486c6c26", null ],
    [ "LEASE_CMDS_DEL4_FAILED", "d6/def/lease__cmds__messages_8cc.html#ac2fba912253a37f2a7852051876aa3ef", null ],
    [ "LEASE_CMDS_DEL6", "d6/def/lease__cmds__messages_8cc.html#a384afcfca9b608ab55aaba57cee1d21e", null ],
    [ "LEASE_CMDS_DEL6_FAILED", "d6/def/lease__cmds__messages_8cc.html#ae0cc9c697e8462f5bb9449245aef58df", null ],
    [ "LEASE_CMDS_GET4_FAILED", "d6/def/lease__cmds__messages_8cc.html#abf61594791e6344caed22efe8c654fc4", null ],
    [ "LEASE_CMDS_GET6_FAILED", "d6/def/lease__cmds__messages_8cc.html#aa9884f3acd58a269e5a6de6fc88804cb", null ],
    [ "LEASE_CMDS_INIT_FAILED", "d6/def/lease__cmds__messages_8cc.html#a547ea7094067739fe67d9f2c46da8d11", null ],
    [ "LEASE_CMDS_INIT_OK", "d6/def/lease__cmds__messages_8cc.html#a1b45a3bd141ed7762ba754027a035b45", null ],
    [ "LEASE_CMDS_RESEND_DDNS4", "d6/def/lease__cmds__messages_8cc.html#aa91d19c6cac692190495933cfc28a53c", null ],
    [ "LEASE_CMDS_RESEND_DDNS4_FAILED", "d6/def/lease__cmds__messages_8cc.html#a24f072c53e20bf49ed6ebbf22b447b92", null ],
    [ "LEASE_CMDS_RESEND_DDNS6", "d6/def/lease__cmds__messages_8cc.html#abc501cbc98f89ac319a5dba230097c7e", null ],
    [ "LEASE_CMDS_RESEND_DDNS6_FAILED", "d6/def/lease__cmds__messages_8cc.html#abaf2b723ed7ee919e494914995a382b0", null ],
    [ "LEASE_CMDS_UPDATE4", "d6/def/lease__cmds__messages_8cc.html#acb34f0980433381312ef81126e113b28", null ],
    [ "LEASE_CMDS_UPDATE4_CONFLICT", "d6/def/lease__cmds__messages_8cc.html#a217f1fefe93aff0c660236f883197f1d", null ],
    [ "LEASE_CMDS_UPDATE4_FAILED", "d6/def/lease__cmds__messages_8cc.html#a1ef0303f15f7d02cd77894ada2307f04", null ],
    [ "LEASE_CMDS_UPDATE6", "d6/def/lease__cmds__messages_8cc.html#aa4333767c12dede6cf72eccc904398e0", null ],
    [ "LEASE_CMDS_UPDATE6_CONFLICT", "d6/def/lease__cmds__messages_8cc.html#a21459f6d8691968b4d4b96ea9c36a39d", null ],
    [ "LEASE_CMDS_UPDATE6_FAILED", "d6/def/lease__cmds__messages_8cc.html#a1679a6aa465b1a609e3f52055215d3a5", null ],
    [ "LEASE_CMDS_WIPE4", "d6/def/lease__cmds__messages_8cc.html#aaccfc09f2dd14d84e5239f3a13553518", null ],
    [ "LEASE_CMDS_WIPE4_DEPRECATED", "d6/def/lease__cmds__messages_8cc.html#a076bd8802d2f3bea4e41d667e27f87dd", null ],
    [ "LEASE_CMDS_WIPE4_FAILED", "d6/def/lease__cmds__messages_8cc.html#a15889fd7901bfffd1595a93b6782a0a6", null ],
    [ "LEASE_CMDS_WIPE6", "d6/def/lease__cmds__messages_8cc.html#a91c99aa73dec2a5d4b5c8d252a1a59b3", null ],
    [ "LEASE_CMDS_WIPE6_DEPRECATED", "d6/def/lease__cmds__messages_8cc.html#a71cf8a5982b6bb979ca3948b0820b5af", null ],
    [ "LEASE_CMDS_WIPE6_FAILED", "d6/def/lease__cmds__messages_8cc.html#a1fb97931cc4f37778277f4d04d5860ca", null ]
];

==> kea-docs-3.1.0-1-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/d6/def/lease__cmds__messages_8cc.js <==
var lease__cmds__messages_8cc =
[
    [ "LEASE_CMDS_ADD4", "d6/def/lease__cmds__messages_8cc.html#a8b26cafbe313dea87c4b60e9d2412c36", null ],
    [ "LEASE_CMDS_ADD4_CONFLICT", "d6/def/lease__cmds__messages_8cc.html#ac078b8f536f9c73a17282b7cf724eceb", null ],
    [ "LEASE_CMDS_ADD4_FAILED", "d6/def/lease__cmds__messages_8cc.html#a39b8134e5fe6a43b1953a151991719fe", null ],
    [ "LEASE_CMDS_ADD6", "d6/def/lease__cmds__messages_8cc.html#a872931e538e61db539b0eb6ea7f327e1", null ],
    [ "LEASE_CMDS_ADD6_CONFLICT", "d6/def/lease__cmds__messages_8cc.html#a988c549dc02e2788be0fd470809d82a2", null ],
    [ "LEASE_CMDS_ADD6_FAILED", "d6/def/lease__cmds__messages_8cc.html#ac67f38db4dfddda9cbeb51b7906cca98", null ],
    [ "LEASE_CMDS_BULK_APPLY6", "d6/def/lease__cmds__messages_8cc.html#ab37d3e76f7f362d27e9655949b41158f", null ],
    [ "LEASE_CMDS_BULK_APPLY6_FAILED", "d6/def/lease__cmds__messages_8cc.html#a9b077c8d4dc62189ec1e7a89b6bea11a", null ],
    [ "LEASE_CMDS_DEINIT_OK", "d6/def/lease__cmds__messages_8cc.html#a3eabc702a2efe993afae67a3a0a2f771", null ],
    [ "LEASE_CMDS_DEL4", "d6/def/lease__cmds__messages_8cc.html#a0a2e211528e7ac391e2174f3486c6c26", null ],
    [ "LEASE_CMDS_DEL4_FAILED", "d6/def/lease__cmds__messages_8cc.html#ac2fba912253a37f2a7852051876aa3ef", null ],
    [ "LEASE_CMDS_DEL6", "d6/def/lease__cmds__messages_8cc.html#a384afcfca9b608ab55aaba57cee1d21e", null ],
    [ "LEASE_CMDS_DEL6_FAILED", "d6/def/lease__cmds__messages_8cc.html#ae0cc9c697e8462f5bb9449245aef58df", null ],
    [ "LEASE_CMDS_GET4_FAILED", "d6/def/lease__cmds__messages_8cc.html#abf61594791e6344caed22efe8c654fc4", null ],
    [ "LEASE_CMDS_GET6_FAILED", "d6/def/lease__cmds__messages_8cc.html#aa9884f3acd58a269e5a6de6fc88804cb", null ],
    [ "LEASE_CMDS_INIT_OK", "d6/def/lease__cmds__messages_8cc.html#a1b45a3bd141ed7762ba754027a035b45", null ],
    [ "LEASE_CMDS_LEASE4_OFFER_FAILED", "d6/def/lease__cmds__messages_8cc.html#aa276dbf37f150a8603d69b46760395b9", null ],
    [ "LEASE_CMDS_LEASES4_COMMITTED_FAILED", "d6/def/lease__cmds__messages_8cc.html#acbdeea89177e53b52398dd784ad5f195", null ],
    [ "LEASE_CMDS_LEASES6_COMMITTED_CONFLICT", "d6/def/lease__cmds__messages_8cc.html#ac1ad001b239d7ac5efdea476df9c5cbf", null ],
    [ "LEASE_CMDS_LEASES6_COMMITTED_FAILED", "d6/def/lease__cmds__messages_8cc.html#a96a6b2764695528e973a416c153b9e05", null ],
    [ "LEASE_CMDS_LEASES6_COMMITTED_LEASE_ERROR", "d6/def/lease__cmds__messages_8cc.html#a40ac2fec11fb30dc7c48ff804f253feb", null ],
    [ "LEASE_CMDS_LOAD_ERROR", "d6/def/lease__cmds__messages_8cc.html#ad7ed55c242510e956e4a40d32f8c6366", null ],
    [ "LEASE_CMDS_PATH_SECURITY_WARNING", "d6/def/lease__cmds__messages_8cc.html#a6b754cb268b2119bb67a487f2187b12e", null ],
    [ "LEASE_CMDS_RESEND_DDNS4", "d6/def/lease__cmds__messages_8cc.html#aa91d19c6cac692190495933cfc28a53c", null ],
    [ "LEASE_CMDS_RESEND_DDNS4_FAILED", "d6/def/lease__cmds__messages_8cc.html#a24f072c53e20bf49ed6ebbf22b447b92", null ],
    [ "LEASE_CMDS_RESEND_DDNS6", "d6/def/lease__cmds__messages_8cc.html#abc501cbc98f89ac319a5dba230097c7e", null ],
    [ "LEASE_CMDS_RESEND_DDNS6_FAILED", "d6/def/lease__cmds__messages_8cc.html#abaf2b723ed7ee919e494914995a382b0", null ],
    [ "LEASE_CMDS_UPDATE4", "d6/def/lease__cmds__messages_8cc.html#acb34f0980433381312ef81126e113b28", null ],
    [ "LEASE_CMDS_UPDATE4_CONFLICT", "d6/def/lease__cmds__messages_8cc.html#a217f1fefe93aff0c660236f883197f1d", null ],
    [ "LEASE_CMDS_UPDATE4_FAILED", "d6/def/lease__cmds__messages_8cc.html#a1ef0303f15f7d02cd77894ada2307f04", null ],
    [ "LEASE_CMDS_UPDATE6", "d6/def/lease__cmds__messages_8cc.html#aa4333767c12dede6cf72eccc904398e0", null ],
    [ "LEASE_CMDS_UPDATE6_CONFLICT", "d6/def/lease__cmds__messages_8cc.html#a21459f6d8691968b4d4b96ea9c36a39d", null ],
    [ "LEASE_CMDS_UPDATE6_FAILED", "d6/def/lease__cmds__messages_8cc.html#a1679a6aa465b1a609e3f52055215d3a5", null ],
    [ "LEASE_CMDS_WIPE4", "d6/def/lease__cmds__messages_8cc.html#aaccfc09f2dd14d84e5239f3a13553518", null ],
    [ "LEASE_CMDS_WIPE4_FAILED", "d6/def/lease__cmds__messages_8cc.html#a15889fd7901bfffd1595a93b6782a0a6", null ],
    [ "LEASE_CMDS_WIPE6", "d6/def/lease__cmds__messages_8cc.html#a91c99aa73dec2a5d4b5c8d252a1a59b3", null ],
    [ "LEASE_CMDS_WIPE6_FAILED", "d6/def/lease__cmds__messages_8cc.html#a1fb97931cc4f37778277f4d04d5860ca", null ]
];
